@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
+__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
 
 import os
 
@@ -158,24 +158,30 @@ class warp(GdalAlgorithm):
     def tags(self):
         return self.tr('transform,reproject,crs,srs').split(',')
 
+    def commandName(self):
+        return 'gdalwarp'
+
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
         inLayer = self.parameterAsRasterLayer(parameters, self.INPUT, context)
         out = self.parameterAsOutputLayer(parameters, self.OUTPUT, context)
         sourceCrs = self.parameterAsCrs(parameters, self.SOURCE_CRS, context)
         targetCrs = self.parameterAsCrs(parameters, self.TARGET_CRS, context)
-        nodata = self.parameterAsDouble(parameters, self.NODATA, context)
+        if self.NODATA in parameters and parameters[self.NODATA] is not None:
+            nodata = self.parameterAsDouble(parameters, self.NODATA, context)
+        else:
+            nodata = None
         resolution = self.parameterAsDouble(parameters, self.TARGET_RESOLUTION, context)
 
         arguments = []
         if sourceCrs.isValid():
             arguments.append('-s_srs')
-            arguments.append(sourceCrs.authid())
+            arguments.append(GdalUtils.gdal_crs_string(sourceCrs))
 
         if targetCrs.isValid():
             arguments.append('-t_srs')
-            arguments.append(targetCrs.authid())
+            arguments.append(GdalUtils.gdal_crs_string(targetCrs))
 
-        if nodata:
+        if nodata is not None:
             arguments.append('-dstnodata')
             arguments.append(str(nodata))
 
@@ -217,4 +223,4 @@ class warp(GdalAlgorithm):
         arguments.append(inLayer.source())
         arguments.append(out)
 
-        return ['gdalwarp', GdalUtils.escapeAndJoin(arguments)]
+        return [self.commandName(), GdalUtils.escapeAndJoin(arguments)]
