@@ -23,15 +23,15 @@ __copyright__ = '(C) 2015, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'
+__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
 
 from .v_net import incorporatePoints, variableOutput
 
 
-def processCommand(alg, parameters, context):
-    incorporatePoints(alg, parameters, context)
+def processCommand(alg, parameters, context, feedback):
+    incorporatePoints(alg, parameters, context, feedback)
 
 
-def processOutputs(alg, parameters, context):
+def processOutputs(alg, parameters, context, feedback):
     outputParameter = {'output': ['output', 'line', 1, False]}
     variableOutput(alg, outputParameter, parameters, context)
