@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'
+__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
 
 
 def checkParameterValuesBeforeExecuting(alg, parameters, context):
@@ -36,10 +36,10 @@ def checkParameterValuesBeforeExecuting(alg, parameters, context):
     return None
 
 
-def processInputs(alg, parameters, context):
+def processInputs(alg, parameters, context, feedback):
     if 'input' in alg.exportedLayers:
         return
 
     # We need to import the vector layer with v.in.ogr
-    alg.loadVectorLayerFromParameter('input', parameters, context, False)
+    alg.loadVectorLayerFromParameter('input', parameters, context, feedback, False)
     alg.postInputs()
